From 05bd6b2010b55a9f0c67cdfc99710bb2e6906a04 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Sat, 3 Feb 2024 16:22:27 +0100
Subject: [PATCH 01/28] Update install.sh
Solved bug with wrong EXE-Link from Autodesk!
---
files/builds/stable-branch/bin/install.sh | 9 +++++----
1 file changed, 5 insertions(+), 4 deletions(-)
diff --git a/files/builds/stable-branch/bin/install.sh b/files/builds/stable-branch/bin/install.sh
index 44ca8d4..ff16a53 100644
--- a/files/builds/stable-branch/bin/install.sh
+++ b/files/builds/stable-branch/bin/install.sh
@@ -6,9 +6,9 @@
# Author: Steve Zabka #
# Author URI: https://cryinkfly.com #
# License: MIT #
-# Copyright (c) 2020-2023 #
-# Time/Date: 12:10/23.09.2023 #
-# Version: 1.9.3 #
+# Copyright (c) 2020-2024 #
+# Time/Date: 16:15/03.02.2024 #
+# Version: 1.9.4 #
####################################################################################################
# Path: /$HOME/.fusion360/bin/install.sh
@@ -45,7 +45,8 @@ REQUIRED_COMMANDS=(
)
# URL to download Fusion360Installer.exe
-SP_FUSION360_INSTALLER_URL="https://dl.appstreaming.autodesk.com/production/installers/Fusion%20360%20Admin%20Install.exe"
+#SP_FUSION360_INSTALLER_URL="https://dl.appstreaming.autodesk.com/production/installers/Fusion%20360%20Admin%20Install.exe" <-- Old Link!!!
+SP_FUSION360_INSTALLER_URL="https://dl.appstreaming.autodesk.com/production/installers/Fusion%20Admin%20Install.exe"
###############################################################################################################################################################
From 8f1d610dbddcf9df8c69aac895fc5a9a6219abcd Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Sat, 3 Feb 2024 16:29:44 +0100
Subject: [PATCH 02/28] Update README.md
---
README.md | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/README.md b/README.md
index e0ca17b..ae16348 100644
--- a/README.md
+++ b/README.md
@@ -322,7 +322,7 @@
-> This bug has been fixed!
- mkdir -p "$HOME/.fusion360/bin" && cd "$HOME/.fusion360/bin" && wget -N https://raw.githubusercontent.com/alextrical/Autodesk-Fusion-360-for-Linux/main/files/builds/stable-branch/bin/install.sh && chmod +x install.sh && ./install.sh
+ mkdir -p "$HOME/.fusion360/bin" && cd "$HOME/.fusion360/bin" && wget -N https://raw.githubusercontent.com/alextrical/Autodesk-Fusion-360-for-Linux/main/files/builds/stable-branch/bin/install.sh && chmod +x install.sh && ./install.sh
🔹 Or you install and use Autodesk Fusion 360 as a Flatpak app:
From 7f52def3238465dccd0ea4eedf5981c88351ab6a Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:06:24 +0100
Subject: [PATCH 04/28] Update locale-cs.sh
---
files/builds/stable-branch/locale/cs-CZ/locale-cs.sh | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/files/builds/stable-branch/locale/cs-CZ/locale-cs.sh b/files/builds/stable-branch/locale/cs-CZ/locale-cs.sh
index e1263f8..3152dfc 100644
--- a/files/builds/stable-branch/locale/cs-CZ/locale-cs.sh
+++ b/files/builds/stable-branch/locale/cs-CZ/locale-cs.sh
@@ -6,9 +6,9 @@
# Author: Steve Zabka #
# Author URI: https://cryinkfly.com #
# License: MIT #
-# Copyright (c) 2020-2022 #
-# Time/Date: 19:00/26.07.2023 #
-# Version: 1.6.2 #
+# Copyright (c) 2020-2024 #
+# Time/Date: 16:00/05.02.2024 #
+# Version: 1.6.3 #
####################################################################################################
# Path: /$HOME/.fusion360/locale/cs-CZ/locale-cs.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="Odstraňte aktuální Wineprefix ze svého
SP_OS_TITLE="Linux distribuce - Konfigurace"
SP_OS_LABEL_1="V tomto kroku nyní můžete vybrat svou distribuci Linuxu a nainstalovat potřebné balíčky pro instalaci."
SP_OS_LABEL_2="Linux distribuce:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 37,Fedora 38,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
###############################################################################################################################################################
@@ -83,7 +83,7 @@ SP_INSTALLDIR_INFO_LABEL_2="Vyberte prosím jiný adresář."
SP_WINE_SETTINGS_TITLE="Vyberte verzi vína"
SP_WINE_SETTINGS_LABEL_1="Zde se musíte rozhodnout mezi dvěma možnostmi*."
SP_WINE_SETTINGS_LABEL_2="Vybrat:"
-SP_WINE_VERSION_SELECT=$(echo "Verze vína (Staging), Verze vína (6.23 nebo vyšší) je již nainstalována v systému!")
+SP_WINE_VERSION_SELECT=$(echo "Verze vína (Staging), Verze vína (8.14 nebo vyšší) je již nainstalována v systému!")
SP_WINE_SETTINGS_LABEL_3="*V závislosti na zvolené možnosti se na váš systém nainstalují další balíčky!"
###############################################################################################################################################################
From 20e0cdf542f1915c377d80ea813de43eac4c682d Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:07:51 +0100
Subject: [PATCH 05/28] Update locale-de.sh
---
files/builds/stable-branch/locale/de-DE/locale-de.sh | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/files/builds/stable-branch/locale/de-DE/locale-de.sh b/files/builds/stable-branch/locale/de-DE/locale-de.sh
index 0616bcd..de74c7d 100644
--- a/files/builds/stable-branch/locale/de-DE/locale-de.sh
+++ b/files/builds/stable-branch/locale/de-DE/locale-de.sh
@@ -6,9 +6,9 @@
# Author: Steve Zabka #
# Author URI: https://cryinkfly.com #
# License: MIT #
-# Copyright (c) 2020-2022 #
-# Time/Date: 19:00/26.07.2023 #
-# Version: 1.6.2 #
+# Copyright (c) 2020-2024 #
+# Time/Date: 16:00/05.02.2024 #
+# Version: 1.6.3 #
####################################################################################################
# Path: /$HOME/.fusion360/locale/de-DE/locale-de.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="Entfernen Sie eine aktuelle Wineprefix von
SP_OS_TITLE="Linux-Distribution - Konfiguration"
SP_OS_LABEL_1="In diesem Schritt können Sie nun Ihre Linux-Distribution auswählen, um die benötigten Pakete für die Installation zu installieren."
SP_OS_LABEL_2="Linux-Distribution:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 37,Fedora 38,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
###############################################################################################################################################################
@@ -83,7 +83,7 @@ SP_INSTALLDIR_INFO_LABEL_2="Bitte wählen Sie ein anderes Verzeichnis."
SP_WINE_SETTINGS_TITLE="Wählen Sie Wine-Version"
SP_WINE_SETTINGS_LABEL_1="Hier müssen Sie sich zwischen zwei Optionen* entscheiden."
SP_WINE_SETTINGS_LABEL_2="Auswählen:"
-SP_WINE_VERSION_SELECT=$(echo "Wine-Version (Staging),Wine-Version (6.23 oder höher) ist bereits auf dem System installiert!")
+SP_WINE_VERSION_SELECT=$(echo "Wine-Version (Staging),Wine-Version (8.14 oder höher) ist bereits auf dem System installiert!")
SP_WINE_SETTINGS_LABEL_3="*Je nach gewählter Option werden weitere Pakete auf Ihrem System installiert!"
###############################################################################################################################################################
From 3ab2edff629df977a7f50113ee95e1255fae8a8f Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:08:27 +0100
Subject: [PATCH 06/28] Update locale-en.sh
---
files/builds/stable-branch/locale/en-US/locale-en.sh | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/files/builds/stable-branch/locale/en-US/locale-en.sh b/files/builds/stable-branch/locale/en-US/locale-en.sh
index e28b378..b899f1a 100644
--- a/files/builds/stable-branch/locale/en-US/locale-en.sh
+++ b/files/builds/stable-branch/locale/en-US/locale-en.sh
@@ -6,9 +6,9 @@
# Author: Steve Zabka #
# Author URI: https://cryinkfly.com #
# License: MIT #
-# Copyright (c) 2020-2022 #
-# Time/Date: 19:00/26.07.2023 #
-# Version: 1.6.2 #
+# Copyright (c) 2020-2024 #
+# Time/Date: 16:00/05.02.2024 #
+# Version: 1.6.3 #
####################################################################################################
# Path: /$HOME/.fusion360/locale/en-EN/locale-en.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="Remove a current Wineprefix from your syst
SP_OS_TITLE="Linux distribution - Configuration"
SP_OS_LABEL_1="In this step you can now select your Linux distribution to install the required packages for the installation."
SP_OS_LABEL_2="Linux distribution:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 37,Fedora 38,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
###############################################################################################################################################################
@@ -83,7 +83,7 @@ SP_INSTALLDIR_INFO_LABEL_2="Please select a different directory."
SP_WINE_SETTINGS_TITLE="Select Wine Version"
SP_WINE_SETTINGS_LABEL_1="Here you have to decide between two options*."
SP_WINE_SETTINGS_LABEL_2="Select:"
-SP_WINE_VERSION_SELECT=$(echo "Wine Version (Staging),Wine version (6.23 or higher) is already installed on the system!")
+SP_WINE_VERSION_SELECT=$(echo "Wine Version (Staging),Wine version (8.14 or higher) is already installed on the system!")
SP_WINE_SETTINGS_LABEL_3="*Depending on which option is selected, further packages will be installed on your system!"
###############################################################################################################################################################
From 72c249dca0a371610b43f043deda868f4bfa692d Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:09:04 +0100
Subject: [PATCH 07/28] Update locale-es.sh
---
files/builds/stable-branch/locale/es-ES/locale-es.sh | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/files/builds/stable-branch/locale/es-ES/locale-es.sh b/files/builds/stable-branch/locale/es-ES/locale-es.sh
index 3579e8b..de03645 100644
--- a/files/builds/stable-branch/locale/es-ES/locale-es.sh
+++ b/files/builds/stable-branch/locale/es-ES/locale-es.sh
@@ -6,9 +6,9 @@
# Author: Steve Zabka #
# Author URI: https://cryinkfly.com #
# License: MIT #
-# Copyright (c) 2020-2022 #
-# Time/Date: 19:00/26.07.2023 #
-# Version: 1.6.2 #
+# Copyright (c) 2020-2024 #
+# Time/Date: 16:00/05.02.2024 #
+# Version: 1.6.3 #
####################################################################################################
# Path: /$HOME/.fusion360/locale/es-ES/locale-es.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="¡Elimine un Wineprefix actual de su siste
SP_OS_TITLE="Distribución Linux - Configuración"
SP_OS_LABEL_1="En este paso ahora puede seleccionar su distribución de Linux para instalar los paquetes necesarios para la instalación."
SP_OS_LABEL_2="Distribución de Linux:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 37,Fedora 38,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
###############################################################################################################################################################
@@ -82,7 +82,7 @@ SP_INSTALLDIR_INFO_LABEL_2="Seleccione un directorio diferente".
SP_WINE_SETTINGS_TITLE="Seleccionar versión de vino"
SP_WINE_SETTINGS_LABEL_1="Aquí tienes que decidir entre dos opciones*."
SP_WINE_SETTINGS_LABEL_2="Seleccionar:"
-SP_WINE_VERSION_SELECT=$(echo "La versión de Wine (puesta en escena), la versión de Wine (6.23 o superior) ya está instalada en el sistema!")
+SP_WINE_VERSION_SELECT=$(echo "La versión de Wine (puesta en escena), la versión de Wine (8.14 o superior) ya está instalada en el sistema!")
SP_WINE_SETTINGS_LABEL_3="*Dependiendo de la opción seleccionada, ¡se instalarán más paquetes en su sistema!"
###############################################################################################################################################################
From 2d7babaed9bd3972ebeadb82abaa4dbd507ffb7c Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:09:45 +0100
Subject: [PATCH 08/28] Update locale-fr.sh
---
files/builds/stable-branch/locale/fr-FR/locale-fr.sh | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/files/builds/stable-branch/locale/fr-FR/locale-fr.sh b/files/builds/stable-branch/locale/fr-FR/locale-fr.sh
index 581a590..e063ccd 100644
--- a/files/builds/stable-branch/locale/fr-FR/locale-fr.sh
+++ b/files/builds/stable-branch/locale/fr-FR/locale-fr.sh
@@ -6,9 +6,9 @@
# Author: Steve Zabka #
# Author URI: https://cryinkfly.com #
# License: MIT #
-# Copyright (c) 2020-2022 #
-# Time/Date: 19:00/26.07.2023 #
-# Version: 1.6.2 #
+# Copyright (c) 2020-2024 #
+# Time/Date: 16:00/05.02.2024 #
+# Version: 1.6.3 #
####################################################################################################
# Path: /$HOME/.fusion360/locale/fr-FR/locale-fr.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="Supprimer un préfixe Wine actuel de votre
SP_OS_TITLE="Distribution Linux - Configuration"
SP_OS_LABEL_1="Dans cette étape, vous pouvez maintenant sélectionner votre distribution Linux pour installer les packages requis pour l'installation."
SP_OS_LABEL_2="Répartition Linux :"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 37,Fedora 38,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
###############################################################################################################################################################
@@ -83,7 +83,7 @@ SP_INSTALLDIR_INFO_LABEL_2="Veuillez sélectionner un autre répertoire."
SP_WINE_SETTINGS_TITLE="Sélectionner la version du vin"
SP_WINE_SETTINGS_LABEL_1="Ici, vous devez choisir entre deux options*."
SP_WINE_SETTINGS_LABEL_2="Sélectionnez :"
-SP_WINE_VERSION_SELECT=$(echo "La version de Wine (Staging), la version de Wine (6.23 ou supérieure) est déjà installée sur le système !")
+SP_WINE_VERSION_SELECT=$(echo "La version de Wine (Staging), la version de Wine (8.14 ou supérieure) est déjà installée sur le système !")
SP_WINE_SETTINGS_LABEL_3="*Selon l'option sélectionnée, d'autres packages seront installés sur votre système !"
###############################################################################################################################################################
From 859c55cfdccec74d1b9a8d1dad95b8f01e4460f8 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:10:23 +0100
Subject: [PATCH 09/28] Update locale-it.sh
---
files/builds/stable-branch/locale/it-IT/locale-it.sh | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/files/builds/stable-branch/locale/it-IT/locale-it.sh b/files/builds/stable-branch/locale/it-IT/locale-it.sh
index c6e350a..734b44a 100644
--- a/files/builds/stable-branch/locale/it-IT/locale-it.sh
+++ b/files/builds/stable-branch/locale/it-IT/locale-it.sh
@@ -6,9 +6,9 @@
# Author: Steve Zabka #
# Author URI: https://cryinkfly.com #
# License: MIT #
-# Copyright (c) 2020-2022 #
-# Time/Date: 19:00/26.07.2023 #
-# Version: 1.6.2 #
+# Copyright (c) 2020-2024 #
+# Time/Date: 16:00/05.02.2024 #
+# Version: 1.6.3 #
####################################################################################################
# Path: /$HOME/.fusion360/locale/it-IT/locale-it.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="Rimuovi un Wineprefix corrente dal tuo sis
SP_OS_TITLE="Distribuzione Linux - Configurazione"
SP_OS_LABEL_1="In questo passaggio puoi ora selezionare la tua distribuzione Linux per installare i pacchetti richiesti per l'installazione."
SP_OS_LABEL_2="Distribuzione Linux:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 37,Fedora 38,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
###############################################################################################################################################################
@@ -83,7 +83,7 @@ SP_INSTALLDIR_INFO_LABEL_2="Seleziona una directory diversa."
SP_WINE_SETTINGS_TITLE="Seleziona versione vino"
SP_WINE_SETTINGS_LABEL_1="Qui devi decidere tra due opzioni*."
SP_WINE_SETTINGS_LABEL_2="Seleziona:"
-SP_WINE_VERSION_SELECT=$(echo "Wine Version (Staging),Wine version (6.23 o successive) è già installata nel sistema!")
+SP_WINE_VERSION_SELECT=$(echo "Wine Version (Staging),Wine version (8.14 o successive) è già installata nel sistema!")
SP_WINE_SETTINGS_LABEL_3="*A seconda dell'opzione selezionata, ulteriori pacchetti verranno installati sul tuo sistema!"
###############################################################################################################################################################
From c9a99bbe949ea47d77f19dcf8a3e19a97260843b Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:10:58 +0100
Subject: [PATCH 10/28] Update locale-ja.sh
---
files/builds/stable-branch/locale/ja-JP/locale-ja.sh | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/files/builds/stable-branch/locale/ja-JP/locale-ja.sh b/files/builds/stable-branch/locale/ja-JP/locale-ja.sh
index 0af5409..9f93b1d 100644
--- a/files/builds/stable-branch/locale/ja-JP/locale-ja.sh
+++ b/files/builds/stable-branch/locale/ja-JP/locale-ja.sh
@@ -6,9 +6,9 @@
# Author: Steve Zabka #
# Author URI: https://cryinkfly.com #
# License: MIT #
-# Copyright (c) 2020-2022 #
-# Time/Date: 19:00/26.07.2023 #
-# Version: 1.6.2 #
+# Copyright (c) 2020-2024 #
+# Time/Date: 16:00/05.02.2024 #
+# Version: 1.6.3 #
####################################################################################################
# Path: /$HOME/.fusion360/locale/ja-JP/locale-ja.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="システムから現在のWineprefixを
SP_OS_TITLE="Linuxディストリビューション-構成"
SP_OS_LABEL_1="このステップでは、Linuxディストリビューションを選択して、インストールに必要なパッケージをインストールできます。"
SP_OS_LABEL_2="Linuxディストリビューション:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 37,Fedora 38,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
###############################################################################################################################################################
@@ -83,7 +83,7 @@ SP_INSTALLDIR_INFO_LABEL_2="別のディレクトリを選択してください
SP_WINE_SETTINGS_TITLE="ワインバージョンの選択"
SP_WINE_SETTINGS_LABEL_1="ここで2つのオプションのどちらかを決定する必要があります*。"
SP_WINE_SETTINGS_LABEL_2="選択:"
-SP_WINE_VERSION_SELECT=$(echo "ワインバージョン(ステージング)、Wineバージョン(6.23以降)はすでにシステムにインストールされています!")
+SP_WINE_VERSION_SELECT=$(echo "ワインバージョン(ステージング)、Wineバージョン(8.14以降)はすでにシステムにインストールされています!")
SP_WINE_SETTINGS_LABEL_3="*選択したオプションに応じて、さらにパッケージがシステムにインストールされます!"
###############################################################################################################################################################
From 3396651e5d43df58e56cceec35db36514bffba1b Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:11:31 +0100
Subject: [PATCH 11/28] Update locale-ko.sh
---
files/builds/stable-branch/locale/ko-KR/locale-ko.sh | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/files/builds/stable-branch/locale/ko-KR/locale-ko.sh b/files/builds/stable-branch/locale/ko-KR/locale-ko.sh
index 61f618b..c0d0f71 100644
--- a/files/builds/stable-branch/locale/ko-KR/locale-ko.sh
+++ b/files/builds/stable-branch/locale/ko-KR/locale-ko.sh
@@ -6,9 +6,9 @@
# Author: Steve Zabka #
# Author URI: https://cryinkfly.com #
# License: MIT #
-# Copyright (c) 2020-2022 #
-# Time/Date: 19:00/26.07.2023 #
-# Version: 1.6.2 #
+# Copyright (c) 2020-2024 #
+# Time/Date: 16:00/05.02.2024 #
+# Version: 1.6.3 #
####################################################################################################
# Path: /$HOME/.fusion360/locale/ko-KR/locale-ko.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="시스템에서 현재 Wineprefix를 제
SP_OS_TITLE="Linux 배포 - 구성"
SP_OS_LABEL_1="이 단계에서는 이제 Linux 배포판을 선택하여 설치에 필요한 패키지를 설치할 수 있습니다."
SP_OS_LABEL_2="Linux 배포판:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 37,Fedora 38,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
###############################################################################################################################################################
@@ -83,7 +83,7 @@ SP_INSTALLDIR_INFO_LABEL_2="다른 디렉토리를 선택하십시오."
SP_WINE_SETTINGS_TITLE="와인 버전 선택"
SP_WINE_SETTINGS_LABEL_1="여기서 두 가지 옵션* 중에서 결정해야 합니다."
SP_WINE_SETTINGS_LABEL_2="선택:"
-SP_WINE_VERSION_SELECT=$(echo "와인 버전(스테이징),Wine 버전(6.23 이상)이 이미 시스템에 설치되어 있습니다!")
+SP_WINE_VERSION_SELECT=$(echo "와인 버전(스테이징),Wine 버전(8.14 이상)이 이미 시스템에 설치되어 있습니다!")
SP_WINE_SETTINGS_LABEL_3="*선택한 옵션에 따라 시스템에 추가 패키지가 설치됩니다!"
###############################################################################################################################################################
From 01daed71b2511750996e63d21747caead28069a5 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:12:01 +0100
Subject: [PATCH 12/28] Update locale-zh.sh
---
files/builds/stable-branch/locale/zh-CN/locale-zh.sh | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/files/builds/stable-branch/locale/zh-CN/locale-zh.sh b/files/builds/stable-branch/locale/zh-CN/locale-zh.sh
index 8616812..8d5e4c3 100644
--- a/files/builds/stable-branch/locale/zh-CN/locale-zh.sh
+++ b/files/builds/stable-branch/locale/zh-CN/locale-zh.sh
@@ -6,9 +6,9 @@
# Author: Steve Zabka #
# Author URI: https://cryinkfly.com #
# License: MIT #
-# Copyright (c) 2020-2022 #
-# Time/Date: 19:00/26.07.2023 #
-# Version: 1.6.2 #
+# Copyright (c) 2020-2024 #
+# Time/Date: 16:00/05.02.2024 #
+# Version: 1.6.3 #
####################################################################################################
# Path: /$HOME/.fusion360/locale/zh-CN/locale-zh.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="从您的系统中删除当前的 Winepref
SP_OS_TITLE="Linux 发行版 - 配置"
SP_OS_LABEL_1="在此步骤中,您现在可以选择您的 Linux 发行版来安装安装所需的软件包。"
SP_OS_LABEL_2="Linux 发行版:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 37,Fedora 38,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
###############################################################################################################################################################
@@ -83,7 +83,7 @@ SP_INSTALLDIR_INFO_LABEL_2="请选择其他目录。"
SP_WINE_SETTINGS_TITLE="选择葡萄酒版本"
SP_WINE_SETTINGS_LABEL_1="你必须在两个选项之间做出决定*。"
SP_WINE_SETTINGS_LABEL_2="选择:"
-SP_WINE_VERSION_SELECT=$(echo "葡萄酒版(分期),Wine 版本(6.23 或更高版本)已安装在系统上!")
+SP_WINE_VERSION_SELECT=$(echo "葡萄酒版(分期),Wine 版本(8.14 或更高版本)已安装在系统上!")
SP_WINE_SETTINGS_LABEL_3="*根据选择的选项,您的系统上将安装更多软件包!"
###############################################################################################################################################################
From 3e8704aa2a3d22c6f7eac9ca648c400bb31ed4e0 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:12:16 +0100
Subject: [PATCH 13/28] Update license-zh.txt
---
files/builds/stable-branch/locale/zh-CN/license-zh.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/files/builds/stable-branch/locale/zh-CN/license-zh.txt b/files/builds/stable-branch/locale/zh-CN/license-zh.txt
index 76d3fac..64853a9 100644
--- a/files/builds/stable-branch/locale/zh-CN/license-zh.txt
+++ b/files/builds/stable-branch/locale/zh-CN/license-zh.txt
@@ -5,7 +5,7 @@
添加一名作者
作者 URI:https://cryinkfly.com
许可证:麻省理工学院
-版权所有 (c) 2020-2023
+版权所有 (c) 2020-2024
特此授予任何人免费获得本软件和相关文档文件(“软件”)副本的许可,不受限制地处理本软件,包括但不限于使用、复制、修改、合并的权利、发布、分发、再许可和/或销售本软件的副本,并允许向其提供本软件的人员这样做,但须符合以下条件:
From 2e708e2c694e2172ac8bb6a08e9f2d19ed5d13d8 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:12:27 +0100
Subject: [PATCH 14/28] Update license-ko.txt
---
files/builds/stable-branch/locale/ko-KR/license-ko.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/files/builds/stable-branch/locale/ko-KR/license-ko.txt b/files/builds/stable-branch/locale/ko-KR/license-ko.txt
index 27e2fc3..3d3b0e6 100644
--- a/files/builds/stable-branch/locale/ko-KR/license-ko.txt
+++ b/files/builds/stable-branch/locale/ko-KR/license-ko.txt
@@ -5,7 +5,7 @@
저자: 스티브 자브카
작성자 URI: https://cryinkfly.com
라이센스: MIT
-저작권 (c) 2020-2023
+저작권 (c) 2020-2024
이에 따라 이 소프트웨어 및 관련 문서 파일("소프트웨어")의 사본을 얻는 모든 사람에게 사용, 복사, 수정, 병합 권한을 포함하되 이에 국한되지 않는 제한 없이 소프트웨어를 다룰 수 있는 권한이 부여됩니다. 다음 조건에 따라 소프트웨어 사본을 게시, 배포, 재라이센스 부여 및/또는 판매하고 소프트웨어가 제공된 사람에게 그렇게 하도록 허용합니다.
From ffe7244a3b77c7698cb8be4181e3916e1b78f6fb Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:12:38 +0100
Subject: [PATCH 15/28] Update license-ja.txt
---
files/builds/stable-branch/locale/ja-JP/license-ja.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/files/builds/stable-branch/locale/ja-JP/license-ja.txt b/files/builds/stable-branch/locale/ja-JP/license-ja.txt
index 4756e9e..0a5f69e 100644
--- a/files/builds/stable-branch/locale/ja-JP/license-ja.txt
+++ b/files/builds/stable-branch/locale/ja-JP/license-ja.txt
@@ -5,7 +5,7 @@
著者:スティーブザブカ
著者URI:https://cryinkfly.com
ライセンス:MIT
-Copyright(c)2020-2023
+Copyright(c)2020-2024
これにより、このソフトウェアおよび関連するドキュメントファイル(「ソフトウェア」)のコピーを取得するすべての人に、使用、コピー、変更、マージの権利を含むがこれに限定されない制限なしにソフトウェアを取り扱う許可が無料で付与されます。 、本ソフトウェアのコピーを公開、配布、サブライセンス、および/または販売すること、および本ソフトウェアが提供される人に、以下の条件を条件として、そうすることを許可すること。
From b462be3f45c0214f429e9151b71b7839eeeb9726 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:12:48 +0100
Subject: [PATCH 16/28] Update license-it.txt
---
files/builds/stable-branch/locale/it-IT/license-it.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/files/builds/stable-branch/locale/it-IT/license-it.txt b/files/builds/stable-branch/locale/it-IT/license-it.txt
index 32394b9..165f034 100644
--- a/files/builds/stable-branch/locale/it-IT/license-it.txt
+++ b/files/builds/stable-branch/locale/it-IT/license-it.txt
@@ -5,7 +5,7 @@ Descrizione: Con questa configurazione guidata è possibile installare Autodesk
Autore: Steve Zabka
URI dell'autore: https://cryinkfly.com
Licenza: MIT
-Copyright (c) 2020-2023
+Copyright (c) 2020-2024
Con la presente viene concessa l'autorizzazione, a titolo gratuito, a chiunque ottenga una copia di questo software e dei file di documentazione associati (il "Software"), di utilizzare il Software senza restrizioni, inclusi senza limitazione i diritti di utilizzare, copiare, modificare, unire , pubblicare, distribuire, concedere in sublicenza e/o vendere copie del Software e consentire alle persone a cui viene fornito il Software di farlo, alle seguenti condizioni:
From a92a6dc3a17914797ef99ac3658834f2d62b5a3a Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:12:59 +0100
Subject: [PATCH 17/28] Update license-fr.txt
---
files/builds/stable-branch/locale/fr-FR/license-fr.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/files/builds/stable-branch/locale/fr-FR/license-fr.txt b/files/builds/stable-branch/locale/fr-FR/license-fr.txt
index 1f967f7..342b70e 100644
--- a/files/builds/stable-branch/locale/fr-FR/license-fr.txt
+++ b/files/builds/stable-branch/locale/fr-FR/license-fr.txt
@@ -5,7 +5,7 @@ Description : Avec cet assistant d'installation, vous pouvez installer Autodesk
Auteur : Steve Zabka
URI de l'auteur : https://cryinkfly.com
Licence : MIT
-Droit d'auteur (c) 2020-2023
+Droit d'auteur (c) 2020-2024
L'autorisation est par la présente accordée, gratuitement, à toute personne obtenant une copie de ce logiciel et des fichiers de documentation associés (le "Logiciel"), de traiter le Logiciel sans restriction, y compris, sans limitation, les droits d'utilisation, de copie, de modification, de fusion , publier, distribuer, sous-licencier et/ou vendre des copies du Logiciel, et permettre aux personnes auxquelles le Logiciel est fourni de le faire, sous réserve des conditions suivantes :
From a5dd5b12febdeadd091bbae103fbffa52ab70ae2 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:13:16 +0100
Subject: [PATCH 18/28] Update license-es.txt
---
files/builds/stable-branch/locale/es-ES/license-es.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/files/builds/stable-branch/locale/es-ES/license-es.txt b/files/builds/stable-branch/locale/es-ES/license-es.txt
index e52700c..a625d5b 100644
--- a/files/builds/stable-branch/locale/es-ES/license-es.txt
+++ b/files/builds/stable-branch/locale/es-ES/license-es.txt
@@ -5,7 +5,7 @@ Descripción: Con este asistente de configuración, puede instalar Autodesk Fusi
Autor: Steve Zabka
URI del autor: https://cryinkfly.com
Licencia: MIT
-Copyright (c) 2020-2023
+Copyright (c) 2020-2024
Por la presente se otorga permiso, sin cargo, a cualquier persona que obtenga una copia de este software y los archivos de documentación asociados (el "Software"), para utilizar el Software sin restricciones, incluidos, entre otros, los derechos de uso, copia, modificación, fusión , publicar, distribuir, sublicenciar y / o vender copias del Software, y permitir que las personas a las que se les proporcione el Software lo hagan, sujeto a las siguientes condiciones:
From 0dd0bbbb7b6dcfa8c0f427f7ea2f0c5b5cbff325 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:13:27 +0100
Subject: [PATCH 19/28] Update license-en.txt
---
files/builds/stable-branch/locale/en-US/license-en.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/files/builds/stable-branch/locale/en-US/license-en.txt b/files/builds/stable-branch/locale/en-US/license-en.txt
index 5ca0d24..504476f 100644
--- a/files/builds/stable-branch/locale/en-US/license-en.txt
+++ b/files/builds/stable-branch/locale/en-US/license-en.txt
@@ -5,7 +5,7 @@ Description: With this Setup Wizard you can install Autodesk Fusion 360 on vario
Author: Steve Zabka
Author URI: https://cryinkfly.com
License: MIT
-Copyright (c) 2020-2023
+Copyright (c) 2020-2024
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
From b34931c008be833565bab067238c91b79ac654f7 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:13:37 +0100
Subject: [PATCH 20/28] Update license-de.txt
---
files/builds/stable-branch/locale/de-DE/license-de.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/files/builds/stable-branch/locale/de-DE/license-de.txt b/files/builds/stable-branch/locale/de-DE/license-de.txt
index 79c32df..0893ee6 100644
--- a/files/builds/stable-branch/locale/de-DE/license-de.txt
+++ b/files/builds/stable-branch/locale/de-DE/license-de.txt
@@ -5,7 +5,7 @@ Beschreibung: Mit diesem Setup-Assistenten können Sie Autodesk Fusion 360 auf v
Autor: Steve Zabka
Autoren-URI: https://cryinkfly.com
Lizenz: MIT
-Copyright (c) 2020-2023
+Copyright (c) 2020-2024
Hiermit wird jeder Person, die eine Kopie dieser Software und der zugehörigen Dokumentationsdateien (die "Software") erhält, kostenlos die Erlaubnis erteilt, mit der Software ohne Einschränkung zu handeln, einschließlich und ohne Einschränkung der Rechte zur Nutzung, zum Kopieren, Ändern, Zusammenführen , Kopien der Software zu veröffentlichen, zu verteilen, unterzulizenzieren und/oder zu verkaufen und Personen, denen die Software zur Verfügung gestellt wird, dies zu gestatten, vorbehaltlich der folgenden Bedingungen:
From 755713661b6fdb2bda4c1ccc007e3d45a48da0f5 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:13:49 +0100
Subject: [PATCH 21/28] Update license-cs.txt
---
files/builds/stable-branch/locale/cs-CZ/license-cs.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/files/builds/stable-branch/locale/cs-CZ/license-cs.txt b/files/builds/stable-branch/locale/cs-CZ/license-cs.txt
index 4266f30..a3195e5 100644
--- a/files/builds/stable-branch/locale/cs-CZ/license-cs.txt
+++ b/files/builds/stable-branch/locale/cs-CZ/license-cs.txt
@@ -5,7 +5,7 @@ Popis: Pomocí tohoto Průvodce instalací můžete nainstalovat Autodesk Fusion
Autor: Steve Zabka
Autor URI: https://cryinkfly.com
Licence: MIT
-Copyright (c) 2020-2023
+Copyright (c) 2020-2024
Tímto se bezplatně uděluje jakékoli osobě, která získá kopii tohoto softwaru a souvisejících dokumentačních souborů (dále jen „software“), nakládat se softwarem bez omezení, mimo jiné včetně práv na používání, kopírování, úpravy, sloučení , publikovat, distribuovat, sublicencovat a/nebo prodávat kopie Softwaru a umožnit osobám, kterým je Software poskytnut, aby tak učinily, za následujících podmínek:
From e25acc918764cae81eb623cbcb5ee57ceee906c7 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:21:16 +0100
Subject: [PATCH 22/28] Update LICENSE.md
---
LICENSE.md | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/LICENSE.md b/LICENSE.md
index 6fd0c0c..7dfda23 100644
--- a/LICENSE.md
+++ b/LICENSE.md
@@ -1,6 +1,6 @@
MIT License
-Copyright (c) 2020-2023 Steve Zabka
+Copyright (c) 2020-2024 Steve Zabka
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
From b658b6cd2132eab360f5c35bd8ca30634bbcd0e7 Mon Sep 17 00:00:00 2001
From: Gianluca Giovinazzo
Date: Tue, 12 Mar 2024 23:56:53 +0100
Subject: [PATCH 23/28] Updated wine install for Ubuntu 23 (From 23.04 to
23.10)
---
files/builds/stable-branch/bin/install.sh | 8 ++++----
files/builds/stable-branch/locale/cs-CZ/locale-cs.sh | 2 +-
files/builds/stable-branch/locale/de-DE/locale-de.sh | 2 +-
files/builds/stable-branch/locale/en-US/locale-en.sh | 2 +-
files/builds/stable-branch/locale/es-ES/locale-es.sh | 2 +-
files/builds/stable-branch/locale/fr-FR/locale-fr.sh | 2 +-
files/builds/stable-branch/locale/it-IT/locale-it.sh | 2 +-
files/builds/stable-branch/locale/ja-JP/locale-ja.sh | 2 +-
files/builds/stable-branch/locale/ko-KR/locale-ko.sh | 2 +-
files/builds/stable-branch/locale/zh-CN/locale-zh.sh | 2 +-
10 files changed, 13 insertions(+), 13 deletions(-)
diff --git a/files/builds/stable-branch/bin/install.sh b/files/builds/stable-branch/bin/install.sh
index a8cef6e..d9bee5f 100644
--- a/files/builds/stable-branch/bin/install.sh
+++ b/files/builds/stable-branch/bin/install.sh
@@ -633,8 +633,8 @@ function OS_UBUNTU_22 {
function OS_UBUNTU_23 {
sudo add-apt-repository -r 'deb https://dl.winehq.org/wine-builds/ubuntu/ lunar main'
- wget -q https://download.opensuse.org/repositories/Emulators:/Wine:/Debian/xUbuntu_23.04/Release.key -O Release.key -O- | sudo apt-key add -
- sudo apt-add-repository 'deb https://download.opensuse.org/repositories/Emulators:/Wine:/Debian/xUbuntu_23.04/ ./'
+ wget -q https://download.opensuse.org/repositories/Emulators:/Wine:/Debian/xUbuntu_23.10/Release.key -O Release.key -O- | sudo apt-key add -
+ sudo apt-add-repository 'deb https://download.opensuse.org/repositories/Emulators:/Wine:/Debian/xUbuntu_23.10/ ./'
}
###############################################################################################################################################################
@@ -1190,8 +1190,8 @@ case "$SP_OS" in
OS_UBUNTU_22
DEBIAN_BASED_2
;;
- "Ubuntu 23.04")
- echo "Ubuntu 23.04"
+ "Ubuntu 23.10")
+ echo "Ubuntu 23.10"
DEBIAN_BASED_1
OS_UBUNTU_23
DEBIAN_BASED_2
diff --git a/files/builds/stable-branch/locale/cs-CZ/locale-cs.sh b/files/builds/stable-branch/locale/cs-CZ/locale-cs.sh
index 3152dfc..a438682 100644
--- a/files/builds/stable-branch/locale/cs-CZ/locale-cs.sh
+++ b/files/builds/stable-branch/locale/cs-CZ/locale-cs.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="Odstraňte aktuální Wineprefix ze svého
SP_OS_TITLE="Linux distribuce - Konfigurace"
SP_OS_LABEL_1="V tomto kroku nyní můžete vybrat svou distribuci Linuxu a nainstalovat potřebné balíčky pro instalaci."
SP_OS_LABEL_2="Linux distribuce:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.10,Void Linux,Gentoo Linux")
###############################################################################################################################################################
diff --git a/files/builds/stable-branch/locale/de-DE/locale-de.sh b/files/builds/stable-branch/locale/de-DE/locale-de.sh
index de74c7d..764417b 100644
--- a/files/builds/stable-branch/locale/de-DE/locale-de.sh
+++ b/files/builds/stable-branch/locale/de-DE/locale-de.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="Entfernen Sie eine aktuelle Wineprefix von
SP_OS_TITLE="Linux-Distribution - Konfiguration"
SP_OS_LABEL_1="In diesem Schritt können Sie nun Ihre Linux-Distribution auswählen, um die benötigten Pakete für die Installation zu installieren."
SP_OS_LABEL_2="Linux-Distribution:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.10,Void Linux,Gentoo Linux")
###############################################################################################################################################################
diff --git a/files/builds/stable-branch/locale/en-US/locale-en.sh b/files/builds/stable-branch/locale/en-US/locale-en.sh
index b899f1a..32a5790 100644
--- a/files/builds/stable-branch/locale/en-US/locale-en.sh
+++ b/files/builds/stable-branch/locale/en-US/locale-en.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="Remove a current Wineprefix from your syst
SP_OS_TITLE="Linux distribution - Configuration"
SP_OS_LABEL_1="In this step you can now select your Linux distribution to install the required packages for the installation."
SP_OS_LABEL_2="Linux distribution:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.10,Void Linux,Gentoo Linux")
###############################################################################################################################################################
diff --git a/files/builds/stable-branch/locale/es-ES/locale-es.sh b/files/builds/stable-branch/locale/es-ES/locale-es.sh
index de03645..67e9e5c 100644
--- a/files/builds/stable-branch/locale/es-ES/locale-es.sh
+++ b/files/builds/stable-branch/locale/es-ES/locale-es.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="¡Elimine un Wineprefix actual de su siste
SP_OS_TITLE="Distribución Linux - Configuración"
SP_OS_LABEL_1="En este paso ahora puede seleccionar su distribución de Linux para instalar los paquetes necesarios para la instalación."
SP_OS_LABEL_2="Distribución de Linux:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.10,Void Linux,Gentoo Linux")
###############################################################################################################################################################
diff --git a/files/builds/stable-branch/locale/fr-FR/locale-fr.sh b/files/builds/stable-branch/locale/fr-FR/locale-fr.sh
index e063ccd..6eb6599 100644
--- a/files/builds/stable-branch/locale/fr-FR/locale-fr.sh
+++ b/files/builds/stable-branch/locale/fr-FR/locale-fr.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="Supprimer un préfixe Wine actuel de votre
SP_OS_TITLE="Distribution Linux - Configuration"
SP_OS_LABEL_1="Dans cette étape, vous pouvez maintenant sélectionner votre distribution Linux pour installer les packages requis pour l'installation."
SP_OS_LABEL_2="Répartition Linux :"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.10,Void Linux,Gentoo Linux")
###############################################################################################################################################################
diff --git a/files/builds/stable-branch/locale/it-IT/locale-it.sh b/files/builds/stable-branch/locale/it-IT/locale-it.sh
index 734b44a..a7638e8 100644
--- a/files/builds/stable-branch/locale/it-IT/locale-it.sh
+++ b/files/builds/stable-branch/locale/it-IT/locale-it.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="Rimuovi un Wineprefix corrente dal tuo sis
SP_OS_TITLE="Distribuzione Linux - Configurazione"
SP_OS_LABEL_1="In questo passaggio puoi ora selezionare la tua distribuzione Linux per installare i pacchetti richiesti per l'installazione."
SP_OS_LABEL_2="Distribuzione Linux:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.10,Void Linux,Gentoo Linux")
###############################################################################################################################################################
diff --git a/files/builds/stable-branch/locale/ja-JP/locale-ja.sh b/files/builds/stable-branch/locale/ja-JP/locale-ja.sh
index 9f93b1d..397107e 100644
--- a/files/builds/stable-branch/locale/ja-JP/locale-ja.sh
+++ b/files/builds/stable-branch/locale/ja-JP/locale-ja.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="システムから現在のWineprefixを
SP_OS_TITLE="Linuxディストリビューション-構成"
SP_OS_LABEL_1="このステップでは、Linuxディストリビューションを選択して、インストールに必要なパッケージをインストールできます。"
SP_OS_LABEL_2="Linuxディストリビューション:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.10,Void Linux,Gentoo Linux")
###############################################################################################################################################################
diff --git a/files/builds/stable-branch/locale/ko-KR/locale-ko.sh b/files/builds/stable-branch/locale/ko-KR/locale-ko.sh
index c0d0f71..406d6cc 100644
--- a/files/builds/stable-branch/locale/ko-KR/locale-ko.sh
+++ b/files/builds/stable-branch/locale/ko-KR/locale-ko.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="시스템에서 현재 Wineprefix를 제
SP_OS_TITLE="Linux 배포 - 구성"
SP_OS_LABEL_1="이 단계에서는 이제 Linux 배포판을 선택하여 설치에 필요한 패키지를 설치할 수 있습니다."
SP_OS_LABEL_2="Linux 배포판:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.10,Void Linux,Gentoo Linux")
###############################################################################################################################################################
diff --git a/files/builds/stable-branch/locale/zh-CN/locale-zh.sh b/files/builds/stable-branch/locale/zh-CN/locale-zh.sh
index 8d5e4c3..cde7881 100644
--- a/files/builds/stable-branch/locale/zh-CN/locale-zh.sh
+++ b/files/builds/stable-branch/locale/zh-CN/locale-zh.sh
@@ -60,7 +60,7 @@ SP_LOGFILE_WINEPREFIX_INFO_TOOLTIP_3="从您的系统中删除当前的 Winepref
SP_OS_TITLE="Linux 发行版 - 配置"
SP_OS_LABEL_1="在此步骤中,您现在可以选择您的 Linux 发行版来安装安装所需的软件包。"
SP_OS_LABEL_2="Linux 发行版:"
-SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.04,Void Linux,Gentoo Linux")
+SP_OS_SELECT=$(echo "Arch Linux,Debian 11,Debian 12, Debian Testing,EndeavourOS,Fedora 38,Fedora 39,Fedora Rawhide,Linux Mint 20.x,Linux Mint 21.x,Linux Mint 5.x - LMDE Version,Manjaro Linux,openSUSE Leap 15.4,openSUSE Leap 15.5,openSUSE Tumbleweed,Red Hat Enterprise Linux 8.x,Red Hat Enterprise Linux 9.x,Solus,Ubuntu 20.04,Ubuntu 22.04,Ubuntu 23.10,Void Linux,Gentoo Linux")
###############################################################################################################################################################
From c4b6e073202ef8ae33fc4185c1ba043f68199740 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 18 Mar 2024 09:39:41 +0100
Subject: [PATCH 24/28] Update install.sh
---
files/builds/stable-branch/bin/install.sh | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/files/builds/stable-branch/bin/install.sh b/files/builds/stable-branch/bin/install.sh
index d9bee5f..ab42a09 100644
--- a/files/builds/stable-branch/bin/install.sh
+++ b/files/builds/stable-branch/bin/install.sh
@@ -7,8 +7,8 @@
# Author URI: https://cryinkfly.com #
# License: MIT #
# Copyright (c) 2020-2024 #
-# Time/Date: 16:00/05.02.2024 #
-# Version: 1.9.5 #
+# Time/Date: 09:40/18.03.2024 #
+# Version: 1.9.6 #
####################################################################################################
# Path: /$HOME/.fusion360/bin/install.sh
From 468b81f178bf9a4ee1b957000232d92729f77373 Mon Sep 17 00:00:00 2001
From: Bailey Buscarino
Date: Sun, 24 Mar 2024 03:22:49 -0400
Subject: [PATCH 25/28] More portable shebang line
---
files/builds/stable-branch/bin/install.sh | 8 ++++----
files/builds/stable-branch/bin/launcher.sh | 2 +-
files/builds/stable-branch/bin/uninstall.sh | 2 +-
files/builds/stable-branch/bin/update.sh | 2 +-
files/builds/stable-branch/locale/cs-CZ/locale-cs.sh | 2 +-
files/builds/stable-branch/locale/de-DE/locale-de.sh | 2 +-
files/builds/stable-branch/locale/en-US/locale-en.sh | 2 +-
files/builds/stable-branch/locale/es-ES/locale-es.sh | 2 +-
files/builds/stable-branch/locale/fr-FR/locale-fr.sh | 2 +-
files/builds/stable-branch/locale/it-IT/locale-it.sh | 2 +-
files/builds/stable-branch/locale/ja-JP/locale-ja.sh | 2 +-
files/builds/stable-branch/locale/ko-KR/locale-ko.sh | 2 +-
files/builds/stable-branch/locale/locale.sh | 2 +-
files/builds/stable-branch/locale/zh-CN/locale-zh.sh | 2 +-
.../development-branch/speech-toolkit/cube_view_home.sh | 2 +-
.../development-branch/speech-toolkit/cube_view_left.sh | 2 +-
.../development-branch/speech-toolkit/cube_view_right.sh | 2 +-
.../development-branch/speech-toolkit/cube_view_top.sh | 2 +-
.../speech-toolkit/get_mouse_location_xy.sh | 2 +-
.../development-branch/speech-toolkit/keypress.sh | 2 +-
files/extras/octoprint-server/octoprint-server-install.sh | 2 +-
21 files changed, 24 insertions(+), 24 deletions(-)
diff --git a/files/builds/stable-branch/bin/install.sh b/files/builds/stable-branch/bin/install.sh
index ab42a09..3111c80 100644
--- a/files/builds/stable-branch/bin/install.sh
+++ b/files/builds/stable-branch/bin/install.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
####################################################################################################
# Name: Autodesk Fusion 360 - Setup Wizard (Linux) #
@@ -7,8 +7,8 @@
# Author URI: https://cryinkfly.com #
# License: MIT #
# Copyright (c) 2020-2024 #
-# Time/Date: 09:40/18.03.2024 #
-# Version: 1.9.6 #
+# Time/Date: 07:29/23.03.2024 #
+# Version: 1.9.7 #
####################################################################################################
# Path: /$HOME/.fusion360/bin/install.sh
@@ -421,7 +421,7 @@ xdg-mime default adskidmgr-opener.desktop x-scheme-handler/adskidmgr
# Create a link to the Wineprefixes Box:
cat >> "$WP_DIRECTORY/box-run.sh" << EOF
-#!/bin/bash
+#!/usr/bin/env bash
WP_BOX='$WP_DIRECTORY' source $SP_PATH/bin/launcher.sh
EOF
chmod +x "$WP_DIRECTORY/box-run.sh"
diff --git a/files/builds/stable-branch/bin/launcher.sh b/files/builds/stable-branch/bin/launcher.sh
index 570d667..9b91124 100644
--- a/files/builds/stable-branch/bin/launcher.sh
+++ b/files/builds/stable-branch/bin/launcher.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
#############################################################################
# Name: Autodesk Fusion 360 - Launcher (Linux) #
diff --git a/files/builds/stable-branch/bin/uninstall.sh b/files/builds/stable-branch/bin/uninstall.sh
index f65b317..cc47d8b 100644
--- a/files/builds/stable-branch/bin/uninstall.sh
+++ b/files/builds/stable-branch/bin/uninstall.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
################################################################################
# Name: Autodesk Fusion 360 - Uninstall the software (Linux) #
diff --git a/files/builds/stable-branch/bin/update.sh b/files/builds/stable-branch/bin/update.sh
index e42c682..2276fe1 100644
--- a/files/builds/stable-branch/bin/update.sh
+++ b/files/builds/stable-branch/bin/update.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
####################################################################################################
# Name: Autodesk Fusion 360 - Cronjob for Update (Linux) #
diff --git a/files/builds/stable-branch/locale/cs-CZ/locale-cs.sh b/files/builds/stable-branch/locale/cs-CZ/locale-cs.sh
index a438682..9fec2ab 100644
--- a/files/builds/stable-branch/locale/cs-CZ/locale-cs.sh
+++ b/files/builds/stable-branch/locale/cs-CZ/locale-cs.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
####################################################################################################
# Name: Autodesk Fusion 360 - Setup Wizard (Linux) #
diff --git a/files/builds/stable-branch/locale/de-DE/locale-de.sh b/files/builds/stable-branch/locale/de-DE/locale-de.sh
index 764417b..2f036ee 100644
--- a/files/builds/stable-branch/locale/de-DE/locale-de.sh
+++ b/files/builds/stable-branch/locale/de-DE/locale-de.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
####################################################################################################
# Name: Autodesk Fusion 360 - Setup Wizard (Linux) #
diff --git a/files/builds/stable-branch/locale/en-US/locale-en.sh b/files/builds/stable-branch/locale/en-US/locale-en.sh
index 32a5790..f57f11c 100644
--- a/files/builds/stable-branch/locale/en-US/locale-en.sh
+++ b/files/builds/stable-branch/locale/en-US/locale-en.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
####################################################################################################
# Name: Autodesk Fusion 360 - Setup Wizard (Linux) #
diff --git a/files/builds/stable-branch/locale/es-ES/locale-es.sh b/files/builds/stable-branch/locale/es-ES/locale-es.sh
index 67e9e5c..b0cf691 100644
--- a/files/builds/stable-branch/locale/es-ES/locale-es.sh
+++ b/files/builds/stable-branch/locale/es-ES/locale-es.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
####################################################################################################
# Name: Autodesk Fusion 360 - Setup Wizard (Linux) #
diff --git a/files/builds/stable-branch/locale/fr-FR/locale-fr.sh b/files/builds/stable-branch/locale/fr-FR/locale-fr.sh
index 6eb6599..3ff3706 100644
--- a/files/builds/stable-branch/locale/fr-FR/locale-fr.sh
+++ b/files/builds/stable-branch/locale/fr-FR/locale-fr.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
####################################################################################################
# Name: Autodesk Fusion 360 - Setup Wizard (Linux) #
diff --git a/files/builds/stable-branch/locale/it-IT/locale-it.sh b/files/builds/stable-branch/locale/it-IT/locale-it.sh
index a7638e8..8843b89 100644
--- a/files/builds/stable-branch/locale/it-IT/locale-it.sh
+++ b/files/builds/stable-branch/locale/it-IT/locale-it.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
####################################################################################################
# Name: Autodesk Fusion 360 - Setup Wizard (Linux) #
diff --git a/files/builds/stable-branch/locale/ja-JP/locale-ja.sh b/files/builds/stable-branch/locale/ja-JP/locale-ja.sh
index 397107e..21bd717 100644
--- a/files/builds/stable-branch/locale/ja-JP/locale-ja.sh
+++ b/files/builds/stable-branch/locale/ja-JP/locale-ja.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
####################################################################################################
# Name: Autodesk Fusion 360 - Setup Wizard (Linux) #
diff --git a/files/builds/stable-branch/locale/ko-KR/locale-ko.sh b/files/builds/stable-branch/locale/ko-KR/locale-ko.sh
index 406d6cc..c549b99 100644
--- a/files/builds/stable-branch/locale/ko-KR/locale-ko.sh
+++ b/files/builds/stable-branch/locale/ko-KR/locale-ko.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
####################################################################################################
# Name: Autodesk Fusion 360 - Setup Wizard (Linux) #
diff --git a/files/builds/stable-branch/locale/locale.sh b/files/builds/stable-branch/locale/locale.sh
index 3af4e4a..725e0fb 100644
--- a/files/builds/stable-branch/locale/locale.sh
+++ b/files/builds/stable-branch/locale/locale.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
####################################################################################################
# Name: Autodesk Fusion 360 - Setup Wizard (Linux) #
diff --git a/files/builds/stable-branch/locale/zh-CN/locale-zh.sh b/files/builds/stable-branch/locale/zh-CN/locale-zh.sh
index cde7881..dff4a43 100644
--- a/files/builds/stable-branch/locale/zh-CN/locale-zh.sh
+++ b/files/builds/stable-branch/locale/zh-CN/locale-zh.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
####################################################################################################
# Name: Autodesk Fusion 360 - Setup Wizard (Linux) #
diff --git a/files/extensions/development-branch/speech-toolkit/cube_view_home.sh b/files/extensions/development-branch/speech-toolkit/cube_view_home.sh
index c366156..1b6f6e8 100644
--- a/files/extensions/development-branch/speech-toolkit/cube_view_home.sh
+++ b/files/extensions/development-branch/speech-toolkit/cube_view_home.sh
@@ -1,3 +1,3 @@
-#!/bin/bash
+#!/usr/bin/env bash
xdotool getactivewindow && xdotool mousemove 1812 181 click 1
\ No newline at end of file
diff --git a/files/extensions/development-branch/speech-toolkit/cube_view_left.sh b/files/extensions/development-branch/speech-toolkit/cube_view_left.sh
index df06d1e..bb160f0 100644
--- a/files/extensions/development-branch/speech-toolkit/cube_view_left.sh
+++ b/files/extensions/development-branch/speech-toolkit/cube_view_left.sh
@@ -1,3 +1,3 @@
-#!/bin/bash
+#!/usr/bin/env bash
xdotool getactivewindow && xdotool mousemove 1825 230 click 1
\ No newline at end of file
diff --git a/files/extensions/development-branch/speech-toolkit/cube_view_right.sh b/files/extensions/development-branch/speech-toolkit/cube_view_right.sh
index cfab061..9505dd3 100644
--- a/files/extensions/development-branch/speech-toolkit/cube_view_right.sh
+++ b/files/extensions/development-branch/speech-toolkit/cube_view_right.sh
@@ -1,3 +1,3 @@
-#!/bin/bash
+#!/usr/bin/env bash
xdotool getactivewindow && xdotool mousemove 1888 228 click 1
\ No newline at end of file
diff --git a/files/extensions/development-branch/speech-toolkit/cube_view_top.sh b/files/extensions/development-branch/speech-toolkit/cube_view_top.sh
index 3fc9692..60b7d6e 100644
--- a/files/extensions/development-branch/speech-toolkit/cube_view_top.sh
+++ b/files/extensions/development-branch/speech-toolkit/cube_view_top.sh
@@ -1,3 +1,3 @@
-#!/bin/bash
+#!/usr/bin/env bash
xdotool getactivewindow && xdotool mousemove 1858 209 click 1
\ No newline at end of file
diff --git a/files/extensions/development-branch/speech-toolkit/get_mouse_location_xy.sh b/files/extensions/development-branch/speech-toolkit/get_mouse_location_xy.sh
index bc7a5c3..2f1dc6e 100644
--- a/files/extensions/development-branch/speech-toolkit/get_mouse_location_xy.sh
+++ b/files/extensions/development-branch/speech-toolkit/get_mouse_location_xy.sh
@@ -1,3 +1,3 @@
-#!/bin/bash
+#!/usr/bin/env bash
xdotool getmouselocation
\ No newline at end of file
diff --git a/files/extensions/development-branch/speech-toolkit/keypress.sh b/files/extensions/development-branch/speech-toolkit/keypress.sh
index 246dd08..13ca1c6 100644
--- a/files/extensions/development-branch/speech-toolkit/keypress.sh
+++ b/files/extensions/development-branch/speech-toolkit/keypress.sh
@@ -1,3 +1,3 @@
-#!/bin/bash
+#!/usr/bin/env bash
xdotool getactivewindow && xdotool keydown $1 && xdotool keyup $1
diff --git a/files/extras/octoprint-server/octoprint-server-install.sh b/files/extras/octoprint-server/octoprint-server-install.sh
index 40a65f9..bb54002 100644
--- a/files/extras/octoprint-server/octoprint-server-install.sh
+++ b/files/extras/octoprint-server/octoprint-server-install.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
##############################################################################
# Name: OctoPrint (Server) - Installationsskript (Linux)
From 25bd29ca228d03a0f78e204fb9235a58607c9505 Mon Sep 17 00:00:00 2001
From: Jiyone <75432524+Jiyone@users.noreply.github.com>
Date: Tue, 26 Mar 2024 12:31:35 +0100
Subject: [PATCH 26/28] Update install.sh Missing "$"
This was making the test failing and the script was downloading the installer each time, even if the installer file already exist.
---
files/builds/stable-branch/bin/install.sh | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/files/builds/stable-branch/bin/install.sh b/files/builds/stable-branch/bin/install.sh
index ab42a09..4316082 100644
--- a/files/builds/stable-branch/bin/install.sh
+++ b/files/builds/stable-branch/bin/install.sh
@@ -325,7 +325,7 @@ function SP_FUSION360_INSTALLER_LOAD {
function SP_WEBVIEW2_INSTALLER_LOAD {
# Search for a existing installer of WEBVIEW2
WEBVIEW2_INSTALLER="$SP_PATH/downloads/WebView2installer.exe"
- if [ -f "WEBVIEW2_INSTALLER" ]; then
+ if [ -f "$WEBVIEW2_INSTALLER" ]; then
echo "The WebView2installer installer exist!"
else
echo "The WebView2installer installer doesn't exist and will be downloaded for you!"
From 5ea74560c4042fd070371692d1a59d597740f113 Mon Sep 17 00:00:00 2001
From: Thermionix
Date: Sun, 5 May 2024 23:29:11 +1000
Subject: [PATCH 27/28] Update install.sh
fix for issue #408
---
files/builds/stable-branch/bin/install.sh | 2 ++
1 file changed, 2 insertions(+)
diff --git a/files/builds/stable-branch/bin/install.sh b/files/builds/stable-branch/bin/install.sh
index dd140a6..1b49adb 100644
--- a/files/builds/stable-branch/bin/install.sh
+++ b/files/builds/stable-branch/bin/install.sh
@@ -528,6 +528,8 @@ function SP_FUSION360_INSTALL {
cp "$SP_PATH/downloads/WebView2installer.exe" "$WP_DIRECTORY/drive_c/users/$USER/Downloads"
WINEPREFIX="$WP_DIRECTORY" wine "$WP_DIRECTORY/drive_c/users/$USER/Downloads/WebView2installer.exe" /install #/silent
sleep 5s
+ # Pre-create shortcut directory for latest re-branding
+ mkdir -p "$WP_DIRECTORY/drive_c/users/$USER/AppData/Roaming/Microsoft/Internet Explorer/Quick Launch/User Pinned/"
# We must copy the EXE-file directly in the Wineprefix folder (Sandbox-Mode)!
cp "$SP_PATH/downloads/Fusion360installer.exe" "$WP_DIRECTORY/drive_c/users/$USER/Downloads"
# This start and stop the installer automatically after a time!
From f6507d49402cbd2e7b486a74f74f641514106bf1 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Sun, 5 May 2024 16:05:06 +0200
Subject: [PATCH 28/28] Update install.sh
---
files/builds/stable-branch/bin/install.sh | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/files/builds/stable-branch/bin/install.sh b/files/builds/stable-branch/bin/install.sh
index 1b49adb..a7aaa00 100644
--- a/files/builds/stable-branch/bin/install.sh
+++ b/files/builds/stable-branch/bin/install.sh
@@ -7,8 +7,8 @@
# Author URI: https://cryinkfly.com #
# License: MIT #
# Copyright (c) 2020-2024 #
-# Time/Date: 07:29/23.03.2024 #
-# Version: 1.9.7 #
+# Time/Date: 16:00/05.05.2024 #
+# Version: 1.9.8 #
####################################################################################################
# Path: /$HOME/.fusion360/bin/install.sh
@@ -169,7 +169,7 @@ fi
function SP_CHECK_WINE_VERSION {
#Wine version checking, warn user if their wine install is out of date
WINE_VERSION="$(wine --version | cut -d ' ' -f1 | sed -e 's/wine-//' -e 's/-rc.*//')"
- WINE_VERSION_MINIMUM=8.14
+ WINE_VERSION_MINIMUM=9.8
if (( $(echo "$WINE_VERSION < $WINE_VERSION_MINIMUM" | bc -l) )); then
echo "Your version of wine ${WINE_VERSION} is too old and will not work with Autodesk Fusion. You should upgrade to at least ${WINE_VERSION_MINIMUM}"
SP_OS_SETTINGS
From 9022ea8375fa2e446c5658f1c10d35d8e07c7837 Mon Sep 17 00:00:00 2001
From: Steve Zabka <79079633+cryinkfly@users.noreply.github.com>
Date: Mon, 5 Feb 2024 16:04:25 +0100
Subject: [PATCH 03/28] Update install.sh
- Solved Issue: #380
- Solved Issue: #381
- Change some Links for Wine versions
- Remove Fedora 37
- Add Fedora 39
---
files/builds/stable-branch/bin/install.sh | 108 +++++++++++++++++-----
1 file changed, 85 insertions(+), 23 deletions(-)
diff --git a/files/builds/stable-branch/bin/install.sh b/files/builds/stable-branch/bin/install.sh
index ff16a53..a8cef6e 100644
--- a/files/builds/stable-branch/bin/install.sh
+++ b/files/builds/stable-branch/bin/install.sh
@@ -7,8 +7,8 @@
# Author URI: https://cryinkfly.com #
# License: MIT #
# Copyright (c) 2020-2024 #
-# Time/Date: 16:15/03.02.2024 #
-# Version: 1.9.4 #
+# Time/Date: 16:00/05.02.2024 #
+# Version: 1.9.5 #
####################################################################################################
# Path: /$HOME/.fusion360/bin/install.sh
@@ -48,6 +48,9 @@ REQUIRED_COMMANDS=(
#SP_FUSION360_INSTALLER_URL="https://dl.appstreaming.autodesk.com/production/installers/Fusion%20360%20Admin%20Install.exe" <-- Old Link!!!
SP_FUSION360_INSTALLER_URL="https://dl.appstreaming.autodesk.com/production/installers/Fusion%20Admin%20Install.exe"
+# URL to download Microsoft Edge WebView2.Exec
+SP_WEBVIEW2_INSTALLER_URL="https://github.com/aedancullen/webview2-evergreen-standalone-installer-archive/releases/download/109.0.1518.78/MicrosoftEdgeWebView2RuntimeInstallerX64.exe"
+
###############################################################################################################################################################
function SP_CHECK_REQUIRED_COMMANDS {
@@ -161,6 +164,20 @@ else
fi
}
+###############################################################################################################################################################
+
+function SP_CHECK_WINE_VERSION {
+ #Wine version checking, warn user if their wine install is out of date
+ WINE_VERSION="$(wine --version | cut -d ' ' -f1 | sed -e 's/wine-//' -e 's/-rc.*//')"
+ WINE_VERSION_MINIMUM=8.14
+ if (( $(echo "$WINE_VERSION < $WINE_VERSION_MINIMUM" | bc -l) )); then
+ echo "Your version of wine ${WINE_VERSION} is too old and will not work with Autodesk Fusion. You should upgrade to at least ${WINE_VERSION_MINIMUM}"
+ SP_OS_SETTINGS
+ else
+ SP_FUSION360_INSTALL
+ fi
+}
+
###############################################################################################################################################################
# ALL LOCALE-FUNCTIONS ARE ARRANGED HERE: #
###############################################################################################################################################################
@@ -278,7 +295,7 @@ esac
}
###############################################################################################################################################################
# DONWLOAD WINETRICKS AND AUTODESK FUSION 360: #
###############################################################################################################################################################
# Load the newest winetricks version:
@@ -302,6 +319,21 @@ function SP_FUSION360_INSTALLER_LOAD {
fi
}
+###############################################################################################################################################################
+
+# Load newest WebView2 installer version for the Setup Wizard!
+function SP_WEBVIEW2_INSTALLER_LOAD {
+ # Search for a existing installer of WEBVIEW2
+ WEBVIEW2_INSTALLER="$SP_PATH/downloads/WebView2installer.exe"
+ if [ -f "WEBVIEW2_INSTALLER" ]; then
+ echo "The WebView2installer installer exist!"
+ else
+ echo "The WebView2installer installer doesn't exist and will be downloaded for you!"
+ wget "$SP_WEBVIEW2_INSTALLER_URL" -cO WebView2installer.exe
+ mv "WebView2installer.exe" "$SP_PATH/downloads/WebView2installer.exe"
+ fi
+}
+
###############################################################################################################################################################
# ALL FUNCTIONS FOR DESKTOP-FILES START HERE: #
###############################################################################################################################################################
@@ -373,6 +405,20 @@ Terminal=false
Path=$SP_PATH/bin
EOF
+ #Create mimetype link to handle web login call backs to the Identity Manager
+ cat > $HOME/.local/share/applications/adskidmgr-opener.desktop << EOL
+[Desktop Entry]
+Type=Application
+Name=adskidmgr Scheme Handler
+Exec=env WINEPREFIX="$WP_DIRECTORY" wine "C:\Program Files\Autodesk\webdeploy\production\99249ee497b13684a43f5bacd5f1f09974049c6b\Autodesk Identity Manager\AdskIdentityManager.exe" %u
+StartupNotify=false
+MimeType=x-scheme-handler/adskidmgr;
+EOL
+xdg-mime default adskidmgr-opener.desktop x-scheme-handler/adskidmgr
+
+ #Disable Debug messages on regular runs, we dont have a terminal, so speed up the system by not wasting time prining them into the Void
+ sed -i 's/=env WINEPREFIX=/=env WINEDEBUG=-all env WINEPREFIX=/g' "$HOME/.local/share/applications/wine/Programs/Autodesk/Fusion360/$WP_TYPE/fusion360.desktop"
+
# Create a link to the Wineprefixes Box:
cat >> "$WP_DIRECTORY/box-run.sh" << EOF
#!/bin/bash
@@ -423,24 +469,24 @@ WP_DRIVER=$(awk 'NR == 2' /tmp/fusion360/settings.txt)
# Start Fusion360installer.exe - Part 1
function SP_FUSION360_INSTALL_DEFAULT_1 {
- WINEPREFIX="$WP_DIRECTORY" timeout -k 10m 9m wine "$WP_DIRECTORY/drive_c/users/$USER/Downloads/Fusion360installer.exe"
+ WINEPREFIX="$WP_DIRECTORY" timeout -k 10m 9m wine "$WP_DIRECTORY/drive_c/users/$USER/Downloads/Fusion360installer.exe" --quiet
}
# Start Fusion360installer.exe - Part 2
function SP_FUSION360_INSTALL_DEFAULT_2 {
- WINEPREFIX="$WP_DIRECTORY" timeout -k 5m 4m wine "$WP_DIRECTORY/drive_c/users/$USER/Downloads/Fusion360installer.exe"
+ WINEPREFIX="$WP_DIRECTORY" timeout -k 5m 4m wine "$WP_DIRECTORY/drive_c/users/$USER/Downloads/Fusion360installer.exe" --quiet
}
###############################################################################################################################################################
# Start Fusion360installer.exe - Part 1 (Refresh)
function SP_FUSION360_INSTALL_REFRESH_1 {
- WINEPREFIX="$WP_WINEPREFIXES_REFRESH" timeout -k 10m 9m wine "$WP_WINEPREFIXES_REFRESH/drive_c/users/$USER/Downloads/Fusion360installer.exe"
+ WINEPREFIX="$WP_WINEPREFIXES_REFRESH" timeout -k 10m 9m wine "$WP_WINEPREFIXES_REFRESH/drive_c/users/$USER/Downloads/Fusion360installer.exe" --quiet
}
# Start Fusion360installer.exe - Part 2 (Refresh)
function SP_FUSION360_INSTALL_REFRESH_2 {
- WINEPREFIX="$WP_WINEPREFIXES_REFRESH" timeout -k 5m 4m wine "$WP_WINEPREFIXES_REFRESH/drive_c/users/$USER/Downloads/Fusion360installer.exe"
+ WINEPREFIX="$WP_WINEPREFIXES_REFRESH" timeout -k 5m 4m wine "$WP_WINEPREFIXES_REFRESH/drive_c/users/$USER/Downloads/Fusion360installer.exe" --quiet
}
###############################################################################################################################################################
@@ -449,6 +495,7 @@ function SP_FUSION360_INSTALL_REFRESH_2 {
function SP_FUSION360_INSTALL {
SP_WINETRICKS_LOAD
SP_FUSION360_INSTALLER_LOAD
+ SP_WEBVIEW2_INSTALLER_LOAD
# Note that the winetricks sandbox verb merely removes the desktop integration and Z: drive symlinks and is not a "true" sandbox.
# It protects against errors rather than malice. It's useful for, e.g., keeping games from saving their settings in random subdirectories of your home directory.
# But it still ensures that wine, for example, no longer has access permissions to Home!
@@ -457,8 +504,10 @@ function SP_FUSION360_INSTALL {
cd "$WP_DIRECTORY" || return
WINEPREFIX="$WP_DIRECTORY" sh "$SP_PATH/bin/winetricks" -q sandbox
sleep 5s
+ WINEPREFIX="$WP_DIRECTORY" sh "$SP_PATH/bin/winetricks" -q sandbox
+ sleep 5s
# We must install some packages!
- WINEPREFIX="$WP_DIRECTORY" sh "$SP_PATH/bin/winetricks" -q atmlib gdiplus corefonts cjkfonts dotnet452 msxml4 msxml6 vcrun2017 fontsmooth=rgb winhttp win10
+ WINEPREFIX="$WP_DIRECTORY" sh "$SP_PATH/bin/winetricks" -q atmlib gdiplus arial corefonts cjkfonts dotnet452 msxml4 msxml6 vcrun2017 fontsmooth=rgb winhttp win10
sleep 5s
# We must install cjkfonts again then sometimes it doesn't work in the first time!
WINEPREFIX="$WP_DIRECTORY" sh "$SP_PATH/bin/winetricks" -q cjkfonts
@@ -467,6 +516,18 @@ function SP_FUSION360_INSTALL {
# We must set to Windows 10 again because some other winetricks sometimes set it back to Windows XP!
WINEPREFIX="$WP_DIRECTORY" sh "$SP_PATH/bin/winetricks" -q win10
sleep 5s
+ #Remove tracking metrics/calling home
+ WINEPREFIX="$WP_DIRECTORY" wine REG ADD "HKCU\Software\Wine\DllOverrides" /v "adpclientservice.exe" /t REG_SZ /d "" /f
+ #Navigation bar does not work well with anything other than the wine builtin DX9
+ WINEPREFIX="$WP_DIRECTORY" wine REG ADD "HKCU\Software\Wine\DllOverrides" /v "AdCefWebBrowser.exe" /t REG_SZ /d builtin /f
+ #Use Visual Studio Redist that is bundled with the application
+ WINEPREFIX="$WP_DIRECTORY" wine REG ADD "HKCU\Software\Wine\DllOverrides" /v "msvcp140" /t REG_SZ /d native /f
+ WINEPREFIX="$WP_DIRECTORY" wine REG ADD "HKCU\Software\Wine\DllOverrides" /v "mfc140u" /t REG_SZ /d native /f
+ sleep 5s
+ #Download and install WebView2 to handle Login attempts, required even though we redirect to your default browser
+ cp "$SP_PATH/downloads/WebView2installer.exe" "$WP_DIRECTORY/drive_c/users/$USER/Downloads"
+ WINEPREFIX="$WP_DIRECTORY" wine "$WP_DIRECTORY/drive_c/users/$USER/Downloads/WebView2installer.exe" /install #/silent
+ sleep 5s
# We must copy the EXE-file directly in the Wineprefix folder (Sandbox-Mode)!
cp "$SP_PATH/downloads/Fusion360installer.exe" "$WP_DIRECTORY/drive_c/users/$USER/Downloads"
# This start and stop the installer automatically after a time!
@@ -542,13 +603,13 @@ function DEBIAN_BASED_2 {
function OS_DEBIAN_11 {
sudo apt-add-repository -r 'deb https://dl.winehq.org/wine-builds/debian/ bullseye main'
- wget -q https://download.opensuse.org/repositories/Emulators:/Wine:/Debian/Debian_11//Release.key -O Release.key -O- | sudo apt-key add -
+ wget -q https://download.opensuse.org/repositories/Emulators:/Wine:/Debian/Debian_11/Release.key -O Release.key -O- | sudo apt-key add -
sudo apt-add-repository 'deb https://download.opensuse.org/repositories/Emulators:/Wine:/Debian/Debian_11/ ./'
}
function OS_DEBIAN_12 {
sudo apt-add-repository -r 'deb https://dl.winehq.org/wine-builds/debian/ bookworm main'
- wget -q https://download.opensuse.org/repositories/Emulators:/Wine:/Debian/Debian_12//Release.key -O Release.key -O- | sudo apt-key add -
+ wget -q https://download.opensuse.org/repositories/Emulators:/Wine:/Debian/Debian_12/Release.key -O Release.key -O- | sudo apt-key add -
sudo apt-add-repository 'deb https://download.opensuse.org/repositories/Emulators:/Wine:/Debian/Debian_12/ ./'
}
@@ -589,14 +650,14 @@ function FEDORA_BASED_2 {
SP_FUSION360_INSTALL
}
-function OS_FEDORA_37 {
- sudo dnf config-manager --add-repo https://download.opensuse.org/repositories/Emulators:/Wine:/Fedora/Fedora_37/Emulators:Wine:Fedora.repo
-}
-
function OS_FEDORA_38 {
sudo dnf config-manager --add-repo https://download.opensuse.org/repositories/Emulators:/Wine:/Fedora/Fedora_38/Emulators:Wine:Fedora.repo
}
+function OS_FEDORA_39 {
+ sudo dnf config-manager --add-repo https://download.opensuse.org/repositories/Emulators:/Wine:/Fedora/Fedora_39/Emulators:Wine:Fedora.repo
+}
+
function OS_FEDORA_RAWHIDE {
sudo dnf config-manager --add-repo https://download.opensuse.org/repositories/Emulators:/Wine:/Fedora/Fedora_Rawhide/Emulators:Wine:Fedora.repo
}
@@ -604,13 +665,13 @@ function OS_FEDORA_RAWHIDE {
###############################################################################################################################################################
function OS_OPENSUSE_154 {
- pkexec su -c 'zypper up && zypper rr https://download.opensuse.org/repositories/Emulators:/Wine/openSUSE_Leap_15.4/ wine && zypper ar -cfp 95 https://download.opensuse.org/repositories/Emulators:/Wine/openSUSE_Leap_15.4/ wine && zypper install p7zip-full curl wget wine cabextract'
+ pkexec su -c 'zypper up && zypper rr https://download.opensuse.org/repositories/Emulators:/Wine/15.4/ wine && zypper ar -cfp 95 https://download.opensuse.org/repositories/Emulators:/Wine/15.4/ wine && zypper install p7zip-full curl wget wine cabextract'
SP_FUSION360_INSTALL
}
# Has not been published yet!
function OS_OPENSUSE_155 {
- pkexec su -c 'zypper up && zypper rr https://download.opensuse.org/repositories/Emulators:/Wine/openSUSE_Leap_15.5/ wine && zypper ar -cfp 95 https://download.opensuse.org/repositories/Emulators:/Wine/openSUSE_Leap_15.5/ wine && zypper install p7zip-full curl wget wine cabextract'
+ pkexec su -c 'zypper up && zypper rr https://download.opensuse.org/repositories/Emulators:/Wine/15.5/ wine && zypper ar -cfp 95 https://download.opensuse.org/repositories/Emulators:/Wine/15.5/ wine && zypper install p7zip-full curl wget wine cabextract'
SP_FUSION360_INSTALL
}
@@ -957,7 +1018,7 @@ case "$WINE_VERSION" in
echo "Install Wine on your system!"
SP_OS_SETTINGS
;;
- # German:
+ # German:
"Wine Version (Entwicklungsversion)")
echo "Install Wine on your system!"
SP_OS_SETTINGS
@@ -998,8 +1059,9 @@ case "$WINE_VERSION" in
SP_OS_SETTINGS
;;
*)
- echo "Wine version (6.23 or higher) is already installed on the system!"
- SP_FUSION360_INSTALL
+ echo "Wine version (8.14 or higher) is already installed on the system!"
+ # Check the correct Wine Version before continuing!
+ SP_CHECK_WINE_VERSION
;;
esac
}
@@ -1046,14 +1108,14 @@ case "$SP_OS" in
echo "EndeavourOS"
OS_ARCHLINUX
;;
- "Fedora 37")
- echo "Fedora 37"
+ "Fedora 38")
+ echo "Fedora 38"
FEDORA_BASED_1
OS_FEDORA_37
FEDORA_BASED_2
;;
- "Fedora 38")
- echo "Fedora 38"
+ "Fedora 39")
+ echo "Fedora 39"
FEDORA_BASED_1
OS_FEDORA_38
FEDORA_BASED_2
@@ -278,7 +295,7 @@ esac
}
###############################################################################################################################################################
-# DONWLOAD WINETRICKS AND AUTODESK FUSION 360: #
+# DONWLOAD WINETRICKS, AUTODESK FUSION 360 AND WEBVIEW2: #
###############################################################################################################################################################
# Load the newest winetricks version: